==> mediawiki-1.14.0.tgz: mediawiki/languages/messages/MessagesKrj.php <==
<?php
/** Kinaray-a (Kinaray-a)
 *
 * @ingroup Language
 * @file
 *
 * @author Harvzsf
 * @author Joebertj
 * @author Jose77
 * @author RonaldPanaligan
 */

$messages = array(
# User preference toggles
'tog-underline'            => "Koritan ang dalum kang manga ''link'':",
'tog-highlightbroken'      => 'I-format ang mga guba nga links <a href="" class="new">paryas kaja</a> (alternative: paryas kaja<a href="" class="internal">?</a>).',
'tog-justify'              => 'Tururupungun ang kilid kang manga paragraph',
'tog-hideminor'            => "Tagoon ang gagmay nga ''edit'' sa mga bag-o nga ilis",
'tog-extendwatchlist'      => "Palapadun ang ''watchlist'' agud nga mapakita ang tanan nga ginasogtan nga pag-ilis",
'tog-numberheadings'       => "Automatiko nga togroan kang nomero ang manga ''heading''",
'tog-showtoolbar'          => 'Ipakita ang pangbolig sa pag-ilis (JavaScript)',
'tog-rememberpassword'     => "Tandaan ang akun nga ''log-in'' sa dya nga ''computer''",
'tog-watchcreations'       => "Idogang sa akun nga ''watchlist'' ang manga pahina nga ginpanghimo ko",
'tog-watchdefault'         => "Idogang sa akun nga ''watchlist'' ang manga pahina nga ginpang-''edit'' ko",
'tog-watchmoves'           => "Idogang sa akun nga ''watchlist'' ang manga pahina nga ginpanghalin ko",
'tog-watchdeletion'        => "Idogang sa akun nga ''watchlist'' ang manga pahina nga ginpamara ko",
'tog-previewonfirst'       => 'Ipakita ang preview sa ona nga ilis',
'tog-nocache'              => "Ontatun ang ''page caching''",
'tog-enotifwatchlistpages' => 'Padarhan ako kang e-mail kon may nag-ilis kang pahina nga akun ginabantayan',
'tog-enotifminoredits'     => "Padarhan man ako kang ''e-mail'' tohay sa manga gagmay nga pag-ilis sa manga pahina",
'tog-shownumberswatching'  => "Ipakita ang karakuun kang manga ''user'' nga galantaw",
'tog-forceeditsummary'     => "Paman-an ako kon blanko nga ''edit summary'' ang akun ginapasulud",
'tog-watchlisthideown'     => "Indi pagpakita sa ''watchlist'' ang akun nga manga gin-islan",
'tog-watchlisthidebots'    => "Indi pagpakita sa ''watchlist'' ang manga gin-islan kang bot",
'tog-watchlisthideminor'   => "Indi pagpakita sa ''watchlist'' ang mga gagmay nga inislan",
'tog-nolangconversion'     => "Ontatun ang ''variants conversion''",
'tog-ccmeonemails'         => "Padarhi man ako kang manga ''e-mail'' nga ginpadara ko sa iban nga manga ''user''",

'underline-always'  => 'Pirme gid',
'underline-never'   => 'Indi gid',
'underline-default' => 'Onay nga browser',

# Dates
'sunday'        => 'Domingo',
'monday'        => 'Lones',
'tuesday'       => 'Martes',
'wednesday'     => 'Miyerkoles',
'thursday'      => 'Webes',
'friday'        => 'Biyernes',
'saturday'      => 'Sabado',
'sun'           => 'Dom',
'mon'           => 'Lon',
'tue'           => 'Mar',
'wed'           => 'Miy',
'thu'           => 'Web',
'fri'           => 'Biy',
'sat'           => 'Sab',
'january'       => 'Enero',
'february'      => 'Pebrero',
'march'         => 'Marso',
'april'         => 'Abril',
'may_long'      => 'Mayo',
'june'          => 'Honyo',
'july'          => 'Holyo',
'august'        => 'Agosto',
'september'     => 'Setyembre',
'october'       => 'Oktobre',
'november'      => 'Nobyembre',
'december'      => 'Disyembre',
'january-gen'   => 'Enero',
'february-gen'  => 'Pebrero',
'march-gen'     => 'Marso',
'april-gen'     => 'Abril',
'may-gen'       => 'Abril',
'june-gen'      => 'Honyo',
'july-gen'      => 'Holyo',
'august-gen'    => 'Agosto',
'september-gen' => 'Setyembre',
'october-gen'   => 'Oktobre',
'november-gen'  => 'Nobyembre',
'december-gen'  => 'Disyembre',
'jan'           => 'Ene',
'feb'           => 'Peb',
'apr'           => 'Abr',
'may'           => 'May',
'jun'           => 'Hon',
'jul'           => 'Hol',
'aug'           => 'Ago',
'sep'           => 'Set',
'oct'           => 'Okt',
'nov'           => 'Nob',
'dec'           => 'Dis',

# Categories related messages
'category_header'       => 'Manga artikolo sa "$1"',
'subcategories'         => "Manga ''subcategory''",
'category-media-header' => 'Manga midya sa "$1"',
'category-empty'        => "''Wara it manga artikolo okon medya ang katergorya nga dya.''",

'about'          => 'Angut sa Iwan',
'article'        => 'Pahina kasudlan',
'newwindow'      => "(gabokas sa bag-o nga ''window'')",
'cancel'         => 'Kanselar',
'qbfind'         => 'Sagap',
'qbbrowse'       => 'Bilid',
'qbedit'         => 'Iislan',
'qbpageoptions'  => 'Dya nga Pahina',
'qbpageinfo'     => 'Konteksto',
'qbspecialpages' => 'Manga espesyal nga pahina',
'moredotdotdot'  => 'Raku pa...',
'mypage'         => 'Akun nga pahina',
'anontalk'       => "Istoryahun ang dya nga ''IP''",

'errorpagetitle'    => 'Sayup',
'returnto'          => 'Balik sa $1.',
'help'              => 'Bolig',
'search'            => 'Sagap',
'searchbutton'      => 'Sagap',
'go'                => 'Agto',
'searcharticle'     => 'Agto',
'history'           => 'Kasaysayan kang Pahina',
'history_short'     => 'Kasaysayan',
'updatedmarker'     => 'ginpabag-o halin kang orihi ko nga pagbisita',
'info_short'        => 'Impormasyon',
'printableversion'  => "Bersyon nga sarang ma-''print''",
'permalink'         => "Permanyente nga ''link''",
'print'             => 'Printa',
'edit'              => 'Iislan',
'editthispage'      => 'Islan ang dya nga pahina',
'delete'            => 'Para',
'deletethispage'    => 'Paraun ang dya nga Pahina',
'protect'           => 'Amlig',
'protect_change'    => 'islan ang proteksyon',
'protectthispage'   => 'Amligan ang dya nga pahina',
'unprotect'         => 'huksun ang proteksyon',
'unprotectthispage' => 'Huksun ang proteksyon sa dya nga pahina',
'newpage'           => 'Bag-o nga pahina',
'talkpage'          => 'Sogdanunun ang dya nga pahina',
'talkpagelinktext'  => 'Wakal',
'specialpage'       => 'Espesyal nga Pahina',
'postcomment'       => 'Togro Komento',
'articlepage'       => 'Turukun ang pahina kasudlan',
'talk'              => 'Sogdanunay',
'views'             => 'Manga paglantaw',
'toolbox'           => 'Pangbolig',
'otherlanguages'    => 'Sa iban nga lingwahe',
'redirectpagesub'   => 'Idaho ang pahina',
'protectedpage'     => 'Protektado nga pahina',
'jumpto'            => 'Lompat sa:',
'jumptosearch'      => 'sagap',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Tunggəd sa {{SITENAME}}',
'aboutpage'            => 'Project:Tunggəd',
'disclaimers'          => 'Mga Panginwala',
'disclaimerpage'       => 'Project:Panginwala nga Pangtanan',
'edithelp'             => 'Panoytoy sa Pag-ilis',
'edithelppage'         => 'Help:Pag-ilis',
'faq'                  => 'FAQ',
'faqpage'              => 'Project:FAQ',
'mainpage'             => 'Pono nga Pahina',
'mainpage-description' => 'Pono nga Pahina',
'privacy'              => 'Surundun sa Privacy',
'privacypage'          => 'Project:Surundun sa Privacy',

'badaccess'        => 'Sayup sa lisensya',
'badaccess-group0' => 'Indi kaw ginpasogtan nga himoon ang lihuk nga ginalaum mo.',
'badaccess-groups' => 'Ang imo ginpangayo nga lihuk ay para lang sa mga users sa {{PLURAL:$2|nga grupo|sara sa mga grupo}}: $1.',

'versionrequired'     => 'Version $1 kang MediaWiki kinahanglan',
'versionrequiredtext' => 'Version $1 of MediaWiki kinahanglan para magamit ang page nga ja.
Lantawa sa [[Special:Version|version kang page]].',

'ok'                      => 'OK dun',
'pagetitle'               => '$1 - {{SITENAME}}',
'youhavenewmessages'      => 'May rudyan kaw nga $1 ($2).',
'newmessageslink'         => 'bag-o nga manga mensahe',
'newmessagesdifflink'     => 'orihi nga ilis',
'youhavenewmessagesmulti' => 'May rudyan kaw nga manga bag-o nga mensahe sa $1',
'editsection'             => 'iislan',
'editold'                 => 'iislan',
'toc'                     => 'Manga Sulud',
'showtoc'                 => 'ipakita',
'hidetoc'                 => 'itago',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Pahina',
'nstab-media'     => 'Pahina kang Midya',
'nstab-special'   => 'Espesyal',
'nstab-project'   => 'Pahina kang Proyekto',
'nstab-image'     => 'Inayap',
'nstab-mediawiki' => 'Mensahe',
'nstab-template'  => "''Template''",
'nstab-help'      => 'Pahina kang Panoytoy',
'nstab-category'  => 'Kategorya',

# General errors
'error'                => 'Sayup',
'databaseerror'        => 'Sayup sa database',
'nodb'                 => "Indi mapili ang ''database'' nga $1",
'readonly'             => "Napintalan ang ''database''",
'internalerror'        => 'Sayup internal',
'internalerror_info'   => 'Sayup internal: $1',
'filecopyerror'        => 'Indi makopya ang \'\'file\'\' halin sa "$1" paagto sa "$2".',
'filerenameerror'      => 'Indi maislan ang ngaran kang \'\'file\'\' halin sa "$1" paagto sa "$2".',
'filedeleteerror'      => "Indi mapara ang ''file'' nga \"\$1\".",
'directorycreateerror' => "Indi mahimo ang ''directory'' nga \"\$1\".",
'filenotfound'         => "Indi makita ang ''file'' nga \"\$1\".",
'fileexistserror'      => "Indi makasolat sa ''file'' nga \"\$1\": may amo kadya run nga ''file''",
'viewsource'           => 'Turukun ang ginhalinan',

# Login and logout pages
'remembermypassword' => "Tandaan ang akun nga ''log-in'' sa dya nga ''computer''",
'nologinlink'        => "Himo ka sangka ''account''",
'createaccount'      => "Himo ka ''account''",
'youremail'          => 'E-mail:',
'email'              => 'E-mail',

# Edit pages
'preview' => 'Bilid',

# Preferences page
'skin-preview'      => 'Bilid',
'searchresultshead' => 'Sagap',

# Recent changes
'hide' => 'Itago',
'show' => 'Ipakita',

'upload-file-error' => 'Sayup internal',

# Special:ListFiles
'imgfile' => 'inayap',

# File deletion
'filedelete-submit' => 'Para',

'brokenredirects-edit'   => '(Iislan)',
'brokenredirects-delete' => '(para)',

'withoutinterwiki-submit' => 'Ipakita',

# Book sources
'booksources-go' => 'Agto',

# Special:Categories
'categories' => 'Manga Kategorya',

# Special:LinkSearch
'linksearch-ok' => 'Sagap',

# Special:ListUsers
'listusers-submit' => 'Ipakita',

# E-mail user
'emailmessage' => 'Mensahe',

# Delete
'delete-legend' => 'Para',

# Restrictions (nouns)
'restriction-edit' => 'Iislan',

# Undelete
'undelete-search-submit' => 'Sagap',

'sp-contributions-submit' => 'Sagap',

# What links here
'whatlinkshere-page' => 'Pahina:',
'isredirect'         => 'idaho ang pahina',

# Block/unblock
'ipblocklist-submit' => 'Sagap',

# Tooltip help for the actions
'tooltip-ca-protect'            => 'Amligan ang dya nga pahina',
'tooltip-ca-delete'             => 'Paraun ang dya nga Pahina',
'tooltip-p-logo'                => 'Pono nga Pahina',
'tooltip-n-mainpage'            => 'Agtoni ang Main Page',
'tooltip-n-portal'              => 'Tunggəd sa project, ano pwede mo mahimo, diin mo makita ang mga bagay bagay',
'tooltip-n-currentevents'       => 'Pangita-a ang mga ginhalinan sa mga nagakaratabo sa tulad',
'tooltip-n-recentchanges'       => 'Listahan kang mga bag-o lang na-ilis sa wiki.',
'tooltip-n-randompage'          => 'Magkarga kang random nga page',
'tooltip-n-help'                => 'Lugar kun diin mo masagap.',
'tooltip-t-whatlinkshere'       => 'Listahan kang tanan nga mga wiki pages nga naga-link paagto ja',
'tooltip-t-recentchangeslinked' => 'Mga bag-o lng ilis nga mga page nga naka-link halin sa page nga ja',
'tooltip-feed-rss'              => 'RSS feed para sa page nga ja',
'tooltip-feed-atom'             => 'Atom feed para sa page nga ja',
'tooltip-t-contributions'       => 'Lantawa ang listahan kang mga ginbulig kang user nga ja',
'tooltip-t-emailuser'           => 'Padarhi kang e-mail ang user nga ja',

# Special:NewFiles
'ilsubmit' => 'Sagap',

# action=purge
'confirm_purge_button' => 'OK dun',

# Multipage image navigation
'imgmultigo' => 'Agto!',

# Table pager
'table_pager_limit_submit' => 'Agto',

# Special:Version
'version-specialpages' => 'Manga espesyal nga pahina',

# Special:FilePath
'filepath-page' => 'Inayap:',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Sagap',

# Special:SpecialPages
'specialpages' => 'Manga espesyal nga pahina',

);

==> mediawiki-1.15.5p0.tgz: mediawiki/languages/messages/MessagesKrj.php <==
<?php
/** Kinaray-a (Kinaray-a)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Harvzsf
 * @author Joebertj
 * @author Jose77
 * @author Oxyzen
 * @author RonaldPanaligan
 */

$messages = array(
# User preference toggles
'tog-underline'            => "Koritan ang dalum kang manga ''link'':",
'tog-highlightbroken'      => 'I-format ang mga guba nga links <a href="" class="new">paryas kaja</a> (alternative: paryas kaja<a href="" class="internal">?</a>).',
'tog-justify'              => 'Tururupungun ang kilid kang manga paragraph',
'tog-hideminor'            => "Tagoon ang gagmay nga ''edit'' sa mga bag-o nga ilis",
'tog-extendwatchlist'      => "Palapadun ang ''watchlist'' agud nga mapakita ang tanan nga ginasogtan nga pag-ilis",
'tog-numberheadings'       => "Automatiko nga togroan kang nomero ang manga ''heading''",
'tog-showtoolbar'          => 'Ipakita ang pangbolig sa pag-ilis (JavaScript)',
'tog-rememberpassword'     => "Tandaan ang akun nga ''log-in'' sa dya nga ''computer''",
'tog-watchcreations'       => "Idogang sa akun nga ''watchlist'' ang manga pahina nga ginpanghimo ko",
'tog-watchdefault'         => "Idogang sa akun nga ''watchlist'' ang manga pahina nga ginpang-''edit'' ko",
'tog-watchmoves'           => "Idogang sa akun nga ''watchlist'' ang manga pahina nga ginpanghalin ko",
'tog-watchdeletion'        => "Idogang sa akun nga ''watchlist'' ang manga pahina nga ginpamara ko",
'tog-previewonfirst'       => 'Ipakita ang preview sa ona nga ilis',
'tog-nocache'              => "Ontatun ang ''page caching''",
'tog-enotifwatchlistpages' => 'Padarhan ako kang e-mail kon may nag-ilis kang pahina nga akun ginabantayan',
'tog-enotifminoredits'     => "Padarhan man ako kang ''e-mail'' tohay sa manga gagmay nga pag-ilis sa manga pahina",
'tog-shownumberswatching'  => "Ipakita ang karakuun kang manga ''user'' nga galantaw",
'tog-forceeditsummary'     => "Paman-an ako kon blanko nga ''edit summary'' ang akun ginapasulud",
'tog-watchlisthideown'     => "Indi pagpakita sa ''watchlist'' ang akun nga manga gin-islan",
'tog-watchlisthidebots'    => "Indi pagpakita sa ''watchlist'' ang manga gin-islan kang bot",
'tog-watchlisthideminor'   => "Indi pagpakita sa ''watchlist'' ang mga gagmay nga inislan",
'tog-nolangconversion'     => "Ontatun ang ''variants conversion''",
'tog-ccmeonemails'         => "Padarhi man ako kang manga ''e-mail'' nga ginpadara ko sa iban nga manga ''user''",

'underline-always'  => 'Pirme gid',
'underline-never'   => 'Indi gid',
'underline-default' => 'Onay nga browser',

# Dates
'sunday'        => 'Domingo',
'monday'        => 'Lones',
'tuesday'       => 'Martes',
'wednesday'     => 'Miyerkoles',
'thursday'      => 'Webes',
'friday'        => 'Biyernes',
'saturday'      => 'Sabado',
'sun'           => 'Dom',
'mon'           => 'Lon',
'tue'           => 'Mar',
'wed'           => 'Miy',
'thu'           => 'Web',
'fri'           => 'Biy',
'sat'           => 'Sab',
'january'       => 'Enero',
'february'      => 'Pebrero',
'march'         => 'Marso',
'april'         => 'Abril',
'may_long'      => 'Mayo',
'june'          => 'Honyo',
'july'          => 'Holyo',
'august'        => 'Agosto',
'september'     => 'Setyembre',
'october'       => 'Oktobre',
'november'      => 'Nobyembre',
'december'      => 'Disyembre',
'january-gen'   => 'Enero',
'february-gen'  => 'Pebrero',
'march-gen'     => 'Marso',
'april-gen'     => 'Abril',
'may-gen'       => 'Abril',
'june-gen'      => 'Honyo',
'july-gen'      => 'Holyo',
'august-gen'    => 'Agosto',
'september-gen' => 'Setyembre',
'october-gen'   => 'Oktobre',
'november-gen'  => 'Nobyembre',
'december-gen'  => 'Disyembre',
'jan'           => 'Ene',
'feb'           => 'Peb',
'apr'           => 'Abr',
'may'           => 'May',
'jun'           => 'Hon',
'jul'           => 'Hol',
'aug'           => 'Ago',
'sep'           => 'Set',
'oct'           => 'Okt',
'nov'           => 'Nob',
'dec'           => 'Dis',

# Categories related messages
'category_header'       => 'Manga artikolo sa "$1"',
'subcategories'         => "Manga ''subcategory''",
'category-media-header' => 'Manga midya sa "$1"',
'category-empty'        => "''Wara it manga artikolo okon medya ang katergorya nga dya.''",

'about'          => 'Angut sa Iwan',
'article'        => 'Pahina kasudlan',
'newwindow'      => "(gabokas sa bag-o nga ''window'')",
'cancel'         => 'Kanselar',
'qbfind'         => 'Sagap',
'qbbrowse'       => 'Bilid',
'qbedit'         => 'Iislan',
'qbpageoptions'  => 'Dya nga Pahina',
'qbpageinfo'     => 'Konteksto',
'qbspecialpages' => 'Manga espesyal nga pahina',
'moredotdotdot'  => 'Raku pa...',
'mypage'         => 'Akun nga pahina',
'anontalk'       => "Istoryahun ang dya nga ''IP''",

'errorpagetitle'    => 'Sayup',
'returnto'          => 'Balik sa $1.',
'help'              => 'Bolig',
'search'            => 'Sagap',
'searchbutton'      => 'Sagap',
'go'                => 'Agto',
'searcharticle'     => 'Agto',
'history'           => 'Kasaysayan kang Pahina',
'history_short'     => 'Kasaysayan',
'updatedmarker'     => 'ginpabag-o halin kang orihi ko nga pagbisita',
'info_short'        => 'Impormasyon',
'printableversion'  => "Bersyon nga sarang ma-''print''",
'permalink'         => "Permanyente nga ''link''",
'print'             => 'Printa',
'edit'              => 'Iislan',
'editthispage'      => 'Islan ang dya nga pahina',
'delete'            => 'Para',
'deletethispage'    => 'Paraun ang dya nga Pahina',
'protect'           => 'Amlig',
'protect_change'    => 'islan ang proteksyon',
'protectthispage'   => 'Amligan ang dya nga pahina',
'unprotect'         => 'huksun ang proteksyon',
'unprotectthispage' => 'Huksun ang proteksyon sa dya nga pahina',
'newpage'           => 'Bag-o nga pahina',
'talkpage'          => 'Sogdanunun ang dya nga pahina',
'talkpagelinktext'  => 'Wakal',
'specialpage'       => 'Espesyal nga Pahina',
'postcomment'       => 'Togro Komento',
'articlepage'       => 'Turukun ang pahina kasudlan',
'talk'              => 'Sugilanon',
'views'             => 'Manga paglantaw',
'toolbox'           => 'Pangbolig',
'otherlanguages'    => 'Sa iban nga lingwahe',
'redirectpagesub'   => 'Idaho ang pahina',
'protectedpage'     => 'Protektado nga pahina',
'jumpto'            => 'Lompat sa:',
'jumptosearch'      => 'sagap',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Tunggəd sa {{SITENAME}}',
'aboutpage'            => 'Project:Tunggəd',
'disclaimers'          => 'Mga Panginwala',
'disclaimerpage'       => 'Project:Panginwala nga Pangtanan',
'edithelp'             => 'Panoytoy sa Pag-ilis',
'edithelppage'         => 'Help:Pag-ilis',
'faq'                  => 'FAQ',
'faqpage'              => 'Project:FAQ',
'mainpage'             => 'Pono nga Pahina',
'mainpage-description' => 'Pono nga Pahina',
'privacy'              => 'Surundun sa Privacy',
'privacypage'          => 'Project:Surundun sa Privacy',

'badaccess'        => 'Sayup sa lisensya',
'badaccess-group0' => 'Indi kaw ginpasogtan nga himoon ang lihuk nga ginalaum mo.',
'badaccess-groups' => 'Ang imo ginpangayo nga lihuk ay para lang sa mga users sa {{PLURAL:$2|nga grupo|sara sa mga grupo}}: $1.',

'versionrequired'     => 'Version $1 kang MediaWiki kinahanglan',
'versionrequiredtext' => 'Version $1 of MediaWiki kinahanglan para magamit ang page nga ja.
Lantawa sa [[Special:Version|version kang page]].',

'ok'                      => 'OK dun',
'youhavenewmessages'      => 'May rudyan kaw nga $1 ($2).',
'newmessageslink'         => 'bag-o nga manga mensahe',
'newmessagesdifflink'     => 'orihi nga ilis',
'youhavenewmessagesmulti' => 'May rudyan kaw nga manga bag-o nga mensahe sa $1',
'editsection'             => 'iislan',
'editold'                 => 'iislan',
'toc'                     => 'Manga Sulud',
'showtoc'                 => 'ipakita',
'hidetoc'                 => 'itago',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Pahina',
'nstab-media'     => 'Pahina kang Midya',
'nstab-special'   => 'Espesyal',
'nstab-project'   => 'Pahina kang Proyekto',
'nstab-image'     => 'Inayap',
'nstab-mediawiki' => 'Mensahe',
'nstab-template'  => "''Template''",
'nstab-help'      => 'Pahina kang Panoytoy',
'nstab-category'  => 'Kategorya',

# General errors
'error'                => 'Sayup',
'databaseerror'        => 'Sayup sa database',
'nodb'                 => "Indi mapili ang ''database'' nga $1",
'readonly'             => "Napintalan ang ''database''",
'internalerror'        => 'Sayup internal',
'internalerror_info'   => 'Sayup internal: $1',
'filecopyerror'        => 'Indi makopya ang \'\'file\'\' halin sa "$1" paagto sa "$2".',
'filerenameerror'      => 'Indi maislan ang ngaran kang \'\'file\'\' halin sa "$1" paagto sa "$2".',
'filedeleteerror'      => "Indi mapara ang ''file'' nga \"\$1\".",
'directorycreateerror' => "Indi mahimo ang ''directory'' nga \"\$1\".",
'filenotfound'         => "Indi makita ang ''file'' nga \"\$1\".",
'fileexistserror'      => "Indi makasolat sa ''file'' nga \"\$1\": may amo kadya run nga ''file''",
'viewsource'           => 'Turukun ang ginhalinan',

# Login and logout pages
'remembermypassword' => "Tandaan ang akun nga ''log-in'' sa dya nga ''computer''",
'nologinlink'        => "Himo ka sangka ''account''",
'createaccount'      => "Himo ka ''account''",
'youremail'          => 'E-mail:',
'email'              => 'E-mail',

# Edit pages
'preview' => 'Bilid',

# Preferences page
'skin-preview'      => 'Bilid',
'searchresultshead' => 'Sagap',

# Recent changes
'hide' => 'Itago',
'show' => 'Ipakita',

'upload-file-error' => 'Sayup internal',

# Special:ListFiles
'imgfile' => 'inayap',

# File deletion
'filedelete-submit' => 'Para',

'brokenredirects-edit'   => '(Iislan)',
'brokenredirects-delete' => '(para)',

'withoutinterwiki-submit' => 'Ipakita',

# Book sources
'booksources-go' => 'Agto',

# Special:Categories
'categories' => 'Manga Kategorya',

# Special:LinkSearch
'linksearch-ok' => 'Sagap',

# Special:ListUsers
'listusers-submit' => 'Ipakita',

# E-mail user
'emailmessage' => 'Mensahe',

# Delete
'delete-legend' => 'Para',

# Restrictions (nouns)
'restriction-edit' => 'Iislan',

# Undelete
'undelete-search-submit' => 'Sagap',

'sp-contributions-submit' => 'Sagap',

# What links here
'whatlinkshere-page' => 'Pahina:',
'isredirect'         => 'idaho ang pahina',

# Block/unblock
'ipblocklist-submit' => 'Sagap',

# Tooltip help for the actions
'tooltip-ca-protect'            => 'Amligan ang dya nga pahina',
'tooltip-ca-delete'             => 'Paraun ang dya nga Pahina',
'tooltip-p-logo'                => 'Pono nga Pahina',
'tooltip-n-mainpage'            => 'Agtoni ang Main Page',
'tooltip-n-portal'              => 'Tunggəd sa project, ano pwede mo mahimo, diin mo makita ang mga bagay bagay',
'tooltip-n-currentevents'       => 'Pangita-a ang mga ginhalinan sa mga nagakaratabo sa tulad',
'tooltip-n-recentchanges'       => 'Listahan kang mga bag-o lang na-ilis sa wiki.',
'tooltip-n-randompage'          => 'Magkarga kang random nga page',
'tooltip-n-help'                => 'Lugar kun diin mo masagap.',
'tooltip-t-whatlinkshere'       => 'Listahan kang tanan nga mga wiki pages nga naga-link paagto ja',
'tooltip-t-recentchangeslinked' => 'Mga bag-o lng ilis nga mga page nga naka-link halin sa page nga ja',
'tooltip-feed-rss'              => 'RSS feed para sa page nga ja',
'tooltip-feed-atom'             => 'Atom feed para sa page nga ja',
'tooltip-t-contributions'       => 'Lantawa ang listahan kang mga ginbulig kang user nga ja',
'tooltip-t-emailuser'           => 'Padarhi kang e-mail ang user nga ja',

# Special:NewFiles
'ilsubmit' => 'Sagap',

# action=purge
'confirm_purge_button' => 'OK dun',

# Multipage image navigation
'imgmultigo' => 'Agto!',

# Table pager
'table_pager_limit_submit' => 'Agto',

# Special:Version
'version-specialpages' => 'Manga espesyal nga pahina',

# Special:FilePath
'filepath-page' => 'Inayap:',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Sagap',

# Special:SpecialPages
'specialpages' => 'Manga espesyal nga pahina',

);
